==> ah-react-ui-1.0.34.tgz: package/lib/esm/ui/header-single-page.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import styled from 'styled-components';
export var HeaderSinglePage = function (props) {
    return (_jsxs(Wrapper, { children: [_jsxs(TopRow, { children: [_jsxs(Heading, { children: [_jsx(Title, { children: props.title }), " ", _jsx(SubTitle, { children: props.title })] }), _jsx(Buttons, { children: props.buttons })] }), _jsx(BottomRow, { children: props.children })] }));
};
var TopRow = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  align-content: space-between;\n"], ["\n  display: flex;\n  align-content: space-between;\n"])));
var BottomRow = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Heading = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  display: flex;\n  gap: 20px;\n"], ["\n  display: flex;\n  gap: 20px;\n"])));
var Title = styled.h2(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var SubTitle = styled.h4(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Buttons = styled.div(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Wrapper = styled.div(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  position: sticky;\n  top: 0;\n  z-index: 100;\n  background: #fff;\n  display: flex;\n  flex-direction: column;\n  padding: 20px;\n  border-bottom: 1px solid #ddd;\n  box-shadow: 0 20px 20px #0000000f;\n  justify-content: space-between;\n"], ["\n  position: sticky;\n  top: 0;\n  z-index: 100;\n  background: #fff;\n  display: flex;\n  flex-direction: column;\n  padding: 20px;\n  border-bottom: 1px solid #ddd;\n  box-shadow: 0 20px 20px #0000000f;\n  justify-content: space-between;\n"])));
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;

==> ah-react-ui-1.0.36.tgz: package/lib/esm/ui/header-single-page.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import styled from 'styled-components';
export var HeaderSinglePage = function (props) {
    return (_jsxs(Wrapper, { children: [_jsxs(TopRow, { children: [_jsxs(Heading, { children: [_jsx(Title, { children: props.title }), " ", _jsx(SubTitle, { children: props.subtitle })] }), _jsx(Buttons, { children: props.buttons })] }), _jsx(BottomRow, { children: props.children })] }));
};
var TopRow = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  align-content: space-between;\n"], ["\n  display: flex;\n  align-content: space-between;\n"])));
var BottomRow = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Heading = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  display: flex;\n  gap: 20px;\n"], ["\n  display: flex;\n  gap: 20px;\n"])));
var Title = styled.h2(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var SubTitle = styled.h4(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Buttons = styled.div(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n\n"], ["\n\n"])));
var Wrapper = styled.div(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  position: sticky;\n  top: 0;\n  z-index: 100;\n  background: #fff;\n  display: flex;\n  flex-direction: column;\n  padding: 20px;\n  border-bottom: 1px solid #ddd;\n  box-shadow: 0 20px 20px #0000000f;\n  justify-content: space-between;\n"], ["\n  position: sticky;\n  top: 0;\n  z-index: 100;\n  background: #fff;\n  display: flex;\n  flex-direction: column;\n  padding: 20px;\n  border-bottom: 1px solid #ddd;\n  box-shadow: 0 20px 20px #0000000f;\n  justify-content: space-between;\n"])));
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;
